==> dhcp-agent-0.39.tar.gz: dhcp-agent-0.39/src/dhcp-client-defaults.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-client-defaults.h,v 1.6 2003/06/23 06:04:33 actmodern Exp $
 * 
 * Copyright 2002 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_CLIENT_DEFAULTS_H
#define DHCP_CLIENT_DEFAULTS_H

/* max timeout threshold for DHCP discover messages. */

#define CLIENT_DEFAULT_DHCP_DISCOVER_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for DHCP request messages. */

#define CLIENT_DEFAULT_DHCP_REQUEST_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ARP messages. */

#define CLIENT_DEFAULT_ARP_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ICMP ECHO messages. */

#define CLIENT_DEFAULT_ICMP_ECHO_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ICMP subnet discovery messages. */

#define CLIENT_DEFAULT_ICMP_SUBNET_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* amount of retry for dhcp DISCOVER messages. */

#define CLIENT_DEFAULT_DHCP_DISCOVER_RETRIES 3

/* amount of retry for dhcp REQUEST messages. */

#define CLIENT_DEFAULT_DHCP_REQUEST_RETRIES 3

/* amount of retry for ICMP messages. */

#define CLIENT_DEFAULT_ICMP_RETRIES 3

/* amount of retry for ARP messages. */

#define CLIENT_DEFAULT_ARP_RETRIES 3

/* default MTU to use on interface during initialization
 * and if none is provided and used from the server. */

#define CLIENT_DEFAULT_MTU 1500

/* Default snaplen. This should be set to the default mtu.
 * only change this if you know what you're doing. */

#define CLIENT_DEFAULT_SNAPLEN DEFAULT_MTU 

/* Default hostname: defaults to none (NULL) */

#define CLIENT_DEFAULT_HOSTNAME NULL

/* Whether or not to use ICMP to measure latency to specified
 * routers.  The client will attempt to send an ICMP Echo Request
 * to any routers it receives to measure latency. The client will
 * then make use of the router with the least latency. Non-zero
 * value enables this. */

#define CLIENT_DEFAULT_DO_MEASURE_LATENCY_ICMP 1

/* The default subnet mask. Define this in string format. */

#define CLIENT_DEFAULT_SUBNET_MASK "255.255.255.0"

/* Percent of lease time to use as renew. */

#define CLIENT_DEFAULT_RENEW_PERCENT 50

/* Percent of lease time to use as rebind. */

#define CLIENT_DEFAULT_REBIND_PERCENT 80

#endif /* DHCP_CLIENT_DEFAULTS_H */

==> dhcp-agent-0.40.tar.gz: dhcp-agent-0.40/src/dhcp-client-defaults.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-client-defaults.h,v 1.7 2003/07/06 05:35:33 actmodern Exp $
 * 
 * Copyright 2002 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_CLIENT_DEFAULTS_H
#define DHCP_CLIENT_DEFAULTS_H

/* max timeout threshold for DHCP discover messages. */

#define CLIENT_DEFAULT_DHCP_DISCOVER_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for DHCP request messages. */

#define CLIENT_DEFAULT_DHCP_REQUEST_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ARP messages. */

#define CLIENT_DEFAULT_ARP_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ICMP ECHO messages. */

#define CLIENT_DEFAULT_ICMP_ECHO_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* max timeout threshold for ICMP subnet discovery messages. */

#define CLIENT_DEFAULT_ICMP_SUBNET_TIMEOUT RECOMMENDED_MAX_SECS_WAIT

/* amount of retry for dhcp DISCOVER messages. */

#define CLIENT_DEFAULT_DHCP_DISCOVER_RETRIES 3

/* amount of retry for dhcp REQUEST messages. */

#define CLIENT_DEFAULT_DHCP_REQUEST_RETRIES 3

/* amount of retry for ICMP messages. */

#define CLIENT_DEFAULT_ICMP_RETRIES 3

/* amount of retry for ARP messages. */

#define CLIENT_DEFAULT_ARP_RETRIES 3

/* default MTU to use on interface during initialization
 * and if none is provided and used from the server. */

#define CLIENT_DEFAULT_MTU 1500

/* Default snaplen. This should be set to the default mtu.
 * only change this if you know what you're doing. */

#define CLIENT_DEFAULT_SNAPLEN CLIENT_DEFAULT_MTU 

/* Default hostname: defaults to none (NULL) */

#define CLIENT_DEFAULT_HOSTNAME NULL

/* Whether or not to use ICMP to measure latency to specified
 * routers.  The client will attempt to send an ICMP Echo Request
 * to any routers it receives to measure latency. The client will
 * then make use of the router with the least latency. Non-zero
 * value enables this. */

#define CLIENT_DEFAULT_DO_MEASURE_LATENCY_ICMP 1

/* The default subnet mask. Define this in string format. */

#define CLIENT_DEFAULT_SUBNET_MASK "255.255.255.0"

/* Percent of lease time to use as renew. */

#define CLIENT_DEFAULT_RENEW_PERCENT 50

/* Percent of lease time to use as rebind. */

#define CLIENT_DEFAULT_REBIND_PERCENT 80

#endif /* DHCP_CLIENT_DEFAULTS_H */
